% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/iosam_cge.R
\name{get_flow_values}
\alias{get_flow_values}
\title{Getting flow values from matrices and \code{iosam} objects}
\usage{
get_flow_values(x, prefix = "X", rows, columns)
}
\arguments{
\item{x}{a vector, matrix, object of \code{iosam} class or its part.}

\item{prefix}{(default "X") the name of the output variable.}

\item{rows}{a vector with sectors' names corresponding to the rows
of x (and columns, if parameter 'columns' is missing and
both dimensions of x are greater than 1) to be added to
the output variable's name.}

\item{columns}{a vector with sectors' names corresponding to the
columns of x to be added to the output variable's name
(optional).}
}
\value{
A named list with selected data.
}
\description{
Function \code{get_flow_values} returns a list with variables
in format "X__RowA__ColumnB" and their values.
\itemize{
   \item If x is a matrix or a vector, the list contains variables
   for all its elements. In this case, parameter 'rows' (and
   'columns') is required.
   \item If x is an Input-Output Table of \code{iosam} class or a
   part of an \code{iosam} object, the list contains variables for
   all its elements as well, but the parameters 'rows' and
   'columns' are optional - when not provided, appropriate
   labels are used.
   \item  If x is a Social Accounting Matrix of \code{iosam} class,
   only the part which constitutes an Input-Output Table is used.
   Parameters 'rows' and 'columns' are optional.}
}
\examples{
flowdata <- matrix(c(0, 0, 0, 38.1, 95.74, 133.84, 0, 0, 0, 9.44, 78.80,
                     88.24, 133.84, 88.24, 0, 0, 0, 222.08, 0, 0, 117.39,
                     68.4, 159.29, 345.08, 0, 0, 104.69, 229.14, 334.57,
                     668.4, 133.84, 88.24, 222.08, 345.08, 668.4, 0),
                   6, 6,
                   byrow = TRUE)
rows <- c("L", "K", "Household", "SectorA", "SectorB", "Total")
x <- iosam(flowdata, nproducts = c(2, 2),
           rows = rows, products_ind = c(4, 4))
get_flow_values(x)
get_flow_values(x, rows = c("A", "B"), columns = c("A", "B"))
get_flow_values(x[1, 4:5], rows = c("L"), columns = c("A", "B"))
get_flow_values(x[c("L", "K"), c("SectorA", "SectorB")])


# Run the following code to copy the file with a more detailed example
# (CGE model calibration) to your current working directory.
\dontrun{
file.copy(file.path(system.file("examples", package = "gEcon.iosam"),
                  "cge_calibr_iosam.R"), getwd())
file.copy(file.path(system.file("examples", package = "gEcon.iosam"),
                  "cge_calibr_iosam.gcn"), getwd())
}

}
\keyword{IO}
\keyword{SAM}
\keyword{gEcon}
\keyword{iosam}

