% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/iosam_functions.R
\name{iosam-import}
\alias{iosam-import}
\alias{read_from_database}
\alias{read_iosam}
\title{Importing tables from a .csv file}
\usage{
read_iosam(filename, sep = ";", dec = ",", nproducts, table_ind, data_ind,
  data_dim, add = TRUE, products_ind)

read_from_database(filename, database, add = TRUE)
}
\arguments{
\item{filename}{the location of a .csv file.}

\item{sep}{(default ;) the field separator character.}

\item{dec}{(default ,) the character used in the file for decimal
points.}

\item{nproducts}{a numeric vector, the number of products (or
sectors) in the imported table.}

\item{table_ind}{a numeric vector, indices of the first element of
  the imported matrix, giving the row with column labels
and the column with row labels.}

\item{data_ind}{a numeric vector, indices of the first data element.}

\item{data_dim}{a numeric vector, dimensions of the matrix with data.}

\item{add}{(default TRUE) logical, should the output table include
rows and columns with additional data?}

\item{products_ind}{a numeric vector, indices of the first element
from the intermediate outputs' matrix (if not specified
c(1, 1) will be taken).}

\item{database}{a character string, source of the imported table
('eurostat', 'wiod' or 'gtap').}
}
\value{
An object of \code{iosam} class.
}
\description{
Functions that import data from files and create \code{iosam} objects:
\code{read_iosam} is an universal function while
\code{read_from_database} is designed to import Input-Output Tables
from Eurostat and the World Input-Output Database or Social
Accounting Matrices from the GTAP database.
For tables from Eurostat and WIOD, it is required to change the
cells format to numeric before importing.
}
\examples{
file <- file.path(system.file("extdata", package="gEcon.iosam"),
                  "iot_eurostat.csv")
pl_input_output <- read_from_database(file, database = 'eurostat',
                                      add = TRUE)
summary(pl_input_output)
View(as.matrix(pl_input_output))

data_file <- file.path(system.file("extdata", package = "gEcon.iosam"),
             "calibr_sam.csv")
sam <- read_iosam(data_file,
                  nproducts = c(8, 8),
                  table_ind = c(2, 2),
                  data_ind = c(3, 3),
                  data_dim = c(18, 18),
                  products_ind = c(10, 10))
summary(sam)
View(as.matrix(sam))

# Run the following code to copy the file with a detailed example to
# your current working directory.
\dontrun{
file.copy(file.path(system.file("examples", package="gEcon.iosam"),
                    "databases.R"), getwd())
}

}
\keyword{IO}
\keyword{SAM}
\keyword{iosam}

